==> hal_0.4.7.orig.tar.gz: hal-0.4.7/hald/hald_marshal.h <==

#ifndef __hald_marshal_MARSHAL_H__
#define __hald_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:STRING,BOOL,BOOL (hald_marshal.list:1) */
extern void hald_marshal_VOID__STRING_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);
#define hald_marshal_VOID__STRING_BOOL_BOOL	hald_marshal_VOID__STRING_BOOLEAN_BOOLEAN

/* VOID:STRING (hald_marshal.list:2) */
#define hald_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:OBJECT,BOOL (hald_marshal.list:3) */
extern void hald_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
#define hald_marshal_VOID__OBJECT_BOOL	hald_marshal_VOID__OBJECT_BOOLEAN

/* VOID:OBJECT,STRING,BOOL,BOOL (hald_marshal.list:4) */
extern void hald_marshal_VOID__OBJECT_STRING_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
                                                              const GValue *param_values,
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);
#define hald_marshal_VOID__OBJECT_STRING_BOOL_BOOL	hald_marshal_VOID__OBJECT_STRING_BOOLEAN_BOOLEAN

/* VOID:OBJECT,STRING (hald_marshal.list:5) */
extern void hald_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:VOID (hald_marshal.list:6) */
#define hald_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

G_END_DECLS

#endif /* __hald_marshal_MARSHAL_H__ */

==> hal_0.5.9.orig.tar.gz: hal-0.5.9/hald/hald_marshal.h <==

#ifndef __hald_marshal_MARSHAL_H__
#define __hald_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:OBJECT,STRING,STRING (hald_marshal.list:1) */
extern void hald_marshal_VOID__OBJECT_STRING_STRING (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

/* VOID:STRING,STRING (hald_marshal.list:2) */
extern void hald_marshal_VOID__STRING_STRING (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:STRING,BOOL,BOOL (hald_marshal.list:3) */
extern void hald_marshal_VOID__STRING_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);
#define hald_marshal_VOID__STRING_BOOL_BOOL	hald_marshal_VOID__STRING_BOOLEAN_BOOLEAN

/* VOID:STRING (hald_marshal.list:4) */
#define hald_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:OBJECT,BOOL (hald_marshal.list:5) */
extern void hald_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
#define hald_marshal_VOID__OBJECT_BOOL	hald_marshal_VOID__OBJECT_BOOLEAN

/* VOID:OBJECT,STRING,BOOL,BOOL (hald_marshal.list:6) */
extern void hald_marshal_VOID__OBJECT_STRING_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
                                                              const GValue *param_values,
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);
#define hald_marshal_VOID__OBJECT_STRING_BOOL_BOOL	hald_marshal_VOID__OBJECT_STRING_BOOLEAN_BOOLEAN

/* VOID:OBJECT,STRING (hald_marshal.list:7) */
extern void hald_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:VOID (hald_marshal.list:8) */
#define hald_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

G_END_DECLS

#endif /* __hald_marshal_MARSHAL_H__ */
